local _, private = ...;
local Core = private.Core;
local Gui = private.Gui;
local Bar = private.Gui.Bar;
local DropDown = private.Gui.DropDown;

local OnClick, GenerateOnClick, OnRemove;

local frame = CreateFrame("Frame", "dingerDropDown");
frame.displayMode = "MENU";

function frame:initialize (level)
  if not level then
    return;
  end

  local title = {
    isTitle = 1,
    text = "Select Sound",
    notCheckable = 1,
  };
  
  UIDropDownMenu_AddButton(title, level);
  
  for _, sound in pairs(LibStub("LibSharedMedia-3.0"):List("sound")) do
    local button = {
      text = sound,
      func = GenerateOnClick(sound),
      checked = sound == Bar.GetActiveInterval().sound,
    };
    
    UIDropDownMenu_AddButton(button, level);
  end

  local remove = {
    text = "Remove Interval",
    func = OnRemove,
    checked = false,
  };
  UIDropDownMenu_AddButton(remove, level);
end

function DropDown.getFrame ()
  return frame;
end

function OnClick (sound)
  local percent = Bar.GetActiveInterval().startP;
  local spellName = Gui.GetCurrentSpell();
  
  Core.SetInterval(spellName, percent, sound);
end

function GenerateOnClick (sound)
  return function (...)
           OnClick(sound, ...)
         end;
end

function OnRemove ()
  local percent = Bar.GetActiveInterval().startP;
  Core.RemoveInterval(Gui.GetCurrentSpell(), percent);
end