local _, private = ...;
local Core = private.Core;
local Gui = private.Gui;
local Bar = private.Gui.Bar;

Gui.X_OFFSET = 40;
Gui.Y_OFFSET = -64;

Gui.DING_ENABLED_TEXTURE = "Interface\\COMMON\\VOICECHAT-SPEAKER.png";
Gui.DING_HIGHLIGHT_TEXTURE = "Interface\\COMMON\\VOICECHAT-ON.png";
Gui.DING_DISABLED_TEXTURE = "Interface\\COMMON\\VOICECHAT-MUTED.png";

Gui.SPELLBOOK_BUTTON_NORMAL =
  "Interface\\AddOns\\dinger\\art\\LogoButtonUp.tga";
Gui.SPELLBOOK_BUTTON_PUSHED =
  "Interface\\AddOns\\dinger\\art\\LogoButtonDown.tga";
Gui.SPELLBOOK_BUTTON_SHOW = 
  "Interface\\AddOns\\dinger\\art\\LogoButtonShow.tga";
Gui.SPELLBOOK_BUTTON_HIDE = 
  "Interface\\AddOns\\dinger\\art\\LogoButtonHide.tga";
Gui.SPELLBOOK_BUTTON_HIGHLIGHT =
  "Interface\\BUTTONS\\UI-MicroButton-Hilight.png";


local EMPTY_ICON_TEXTURE = "Interface\\BUTTONS\\UI-EmptySlot-Disabled";

local AddSpell, RemoveSpell, AddButton_OnClick,
RemoveButton_OnClick, ListEntry_OnClick, SpellIconTexture_initialize,
DingerFrameInit, ProfilesFrameInit, SpellsFrameInit;

function Gui.Init ()
  LibStub("LuaToGui"):Create(Gui.dingerFrameTable, SpellBookFrame);
  
  Gui.SetCurrentSpell(nil);
  Gui.SpellBook.Init();
  Gui.Bar.Init(dingerFrame);
  
  dinger.RegisterCallback(Gui, "DINGER_NEW_INTERVAL");
  dinger.RegisterCallback(Gui, "DINGER_REMOVE_INTERVAL");
end

function Gui.SlashCmd ()
  if dingerFrame:IsVisible() then
    dingerFrame:Hide();
  else
    SpellBookFrame:Show();
    dingerFrame:Show();
  end
end

function Gui.DINGER_NEW_INTERVAL (_, _, percent, sound)
  Bar.AddIntervalAtPercent(percent, sound);
end

function Gui.DINGER_REMOVE_INTERVAL (_, _, percent)
  Bar.RemoveIntervalAtPercent(percent, sound);
end

function Gui.SpellBookButtonOnClick()
  if dingerFrame:IsVisible() then
    PlaySound("igCharacterInfoClose");
    dingerFrame:Hide();
  else
    PlaySound("igCharacterInfoOpen");
    dingerFrame:Show();
  end
end

function Gui.DingerFrameOnShow ()
  if dingerSpellbookButton then
    dingerSpellbookButton:SetNormalTexture(Gui.SPELLBOOK_BUTTON_SHOW);
    dingerSpellbookButton:SetPushedTexture(Gui.SPELLBOOK_BUTTON_HIDE);
  end
end

function Gui.DingerFrameOnHide ()
  if dingerSpellbookButton then
    dingerSpellbookButton:SetNormalTexture(Gui.SPELLBOOK_BUTTON_NORMAL);
    dingerSpellbookButton:SetPushedTexture(Gui.SPELLBOOK_BUTTON_PUSHED);
  end
end

do
  
  -- nil if we are adding a new ding
  local currentSpellName;

  function Gui.GetCurrentSpell ()
    return currentSpellName;
  end
  
  function Gui.SetCurrentSpell (spellName)
    currentSpellName = spellName;

    if currentSpellName then
      local _, _, icon = GetSpellInfo(currentSpellName);
      dingerSpellIcon:EnableMouse(false);
      dingerSpellIconTexture:SetTexture(icon);
      dingerSpellIconTexture:SetTexCoord(0, 1, 0, 1);
      dingerSpellIconText:SetText(currentSpellName);
      dingerSpellIconText:SetTextColor(GameFontNormal:GetTextColor());
      dingerClearButton:Enable();
    else
      dingerSpellIcon:EnableMouse(true);
      dingerSpellIconTexture:SetTexture(EMPTY_ICON_TEXTURE);
      dingerSpellIconTexture:SetTexCoord(0.25, 0.75, 0.25, 0.75);
      dingerSpellIconText:SetText("Click on a spell to configure");
      dingerSpellIconText:SetTextColor(1, 1, 1, 1);
      dingerClearButton:Disable();
    end

    Gui.Bar.DisplaySpell(spellName);
  end
  
end