local _, private = ...;
local SpellBook = private.Gui.SpellBook;
local Core = private.Core;
local Gui = private.Gui; 

local configButtonTable = {
  name = "dingerSpellbookButton",
  type = "button",
  height = 55,
  width = 30,
  normalTexture = Gui.SPELLBOOK_BUTTON_NORMAL,
  pushedTexture = Gui.SPELLBOOK_BUTTON_PUSHED,
  highlightTexture = Gui.SPELLBOOK_BUTTON_HIGHLIGHT,
  scripts = {
    OnClick = function (...) Gui.SpellBookButtonOnClick(); end,
  },
  anchors = {
    TOPRIGHT = {
      relativeTo = "!$parent",
      relativePoint = "TOPRIGHT",
      xOff = -20,
      yOff = 0,
    },
  },
};

local spellButtonTable = {
  type = "button",
  highlightTexture = "Interface\\Buttons\\ButtonHilight-Square.png",
  highlightMode = "ADD",
  anchors = {
    -- inject allPoints
  },
  children = {
    {
      name = "$parentTexture1",
      type = "texture",
      height = 20,
      width = 20,
      anchors = {
        TOPRIGHT = {
          relativeTo = "!$parent",
          relativePoint = "TOPRIGHT",
          xOff = 8,
          yOff = 8,
        }
      },
    },
    {
      name = "$parentTexture2",
      type = "texture",
      height = 20,
      width = 20,
      anchors = {
        TOPRIGHT = {
          relativeTo = "!$parent",
          relativePoint = "TOPRIGHT",
          xOff = 8,
          yOff = 8,
        }
      },
    },
  },
};

local NUM_SPELL_BUTTONS = 12;

local spellButtons = {};

local SpellButton = {};

local function Update ()
  for i=1, NUM_SPELL_BUTTONS do
    spellButtons[i]:Update();
  end
end

function SpellBook.Init ()
  LibStub("LuaToGui"):Create(configButtonTable, SpellBookFrameInset);
  CreateFrame("Frame"):SetScript("OnUpdate", Update);
  
  for i=1, NUM_SPELL_BUTTONS do
    spellButtons[i] = SpellButton:New(i);
  end
end

function SpellButton:New (index)
  local spellButton = setmetatable({}, { __index = SpellButton });

  spellButtonTable.name = "dingerSpellButton" .. index;
  spellButtonTable.anchors.allPoints = "!SpellButton" .. index;
  spellButtonTable.frameLevel = _G["SpellButton" .. index]:GetFrameLevel() + 2;
  
  local overlay = LibStub("LuaToGui"):Create(spellButtonTable, dingerFrame);
  spellButton.overlay = overlay;
  
  local function OnClick ()
    spellButton:OnClick();
  end
  
  overlay:SetScript("OnClick", OnClick);
                                                   
  spellButton.button = _G["SpellButton" .. index];
  spellButton.text = _G["SpellButton" .. index .. "SpellName"];

  local name = overlay:GetName();
  spellButton.texture1 = _G[name .. "Texture1"];
  spellButton.texture2 = _G[name .. "Texture2"];

  return spellButton;
end

function SpellButton:SpellName ()
  return self.text:GetText();
end

function SpellButton:MarkActive ()
  self.texture1:SetTexture(Gui.DING_ENABLED_TEXTURE);
  self.texture2:SetTexture(Gui.DING_HIGHLIGHT_TEXTURE);
end

function SpellButton:MarkInactive ()
  self.texture1:SetTexture(Gui.DING_DISABLED_TEXTURE);
  self.texture2:SetTexture(nil);
end

function SpellButton:Update ()
  if not self.text:IsVisible() then
    self.overlay:Hide();
  else
    self.overlay:Show();
    if Core.SpellHasIntervals(self:SpellName()) then
      self:MarkActive();
    else
      self:MarkInactive();
    end
  end
end

function SpellButton:OnClick ()
  PlaySound("igMainMenuContinue");
  Gui.SetCurrentSpell(self:SpellName());
end